@@ -1,4 +1,4 @@
 """Runway CLI."""
 from .main import cli
 
-__all__ = ['cli']
+__all__ = ["cli"]
