@@ -6,11 +6,13 @@ import click
 
 from ... import options
 from ._install import install
+from ._list import list_installed
 from ._run import run
+from ._uninstall import uninstall
 
-__all__ = ["install", "run"]
+__all__ = ["install", "list_installed", "run", "uninstall"]
 
-COMMANDS = [install, run]
+COMMANDS = [install, list_installed, run, uninstall]
 
 
 @click.group("tfenv", short_help="terraform (install|run)")
