@@ -1,17 +1,15 @@
 """CFNgin environment file parsing."""
+from typing import Any, Dict
 
 
-def parse_environment(raw_environment):
+def parse_environment(raw_environment: str) -> Dict[str, Any]:
     """Parse environment file contents.
 
     Args:
-        raw_environment (str): Environment file read into a string.
-
-    Returns:
-        Dict[str, Any]
+        raw_environment: Environment file read into a string.
 
     """
-    environment = {}
+    environment: Dict[str, Any] = {}
     for line in raw_environment.split("\n"):
         line = line.strip()
         if not line:
@@ -23,7 +21,7 @@ def parse_environment(raw_environment):
         try:
             key, value = line.split(":", 1)
         except ValueError:
-            raise ValueError("Environment must be in key: value format")
+            raise ValueError("Environment must be in key: value format") from None
 
         environment[key] = value.strip()
     return environment
