@@ -1,11 +1,13 @@
 """CFNgin exceptions."""
 from __future__ import annotations
 
+from pathlib import Path
 from typing import TYPE_CHECKING, Any, List, Optional, Union
 
 from ..exceptions import RunwayError
 
 if TYPE_CHECKING:
+    from ..type_defs import AnyPath
     from ..variables import Variable
     from .plan import Step
 
@@ -22,6 +24,79 @@ class CancelExecution(CfnginError):
     message: str = "Plan canceled"
 
 
+class CfnginBucketAccessDenied(CfnginError):
+    """Access denied to CFNgin bucket.
+
+    This can occur when the bucket exists in another AWS account and/or the
+    credentials being used do not have adequate permissions to access the bucket.
+
+    """
+
+    bucket_name: str
+    message: str
+
+    def __init__(self, *, bucket_name: str) -> None:
+        """Instantiate class.
+
+        Args:
+            bucket_name: Name of the CFNgin bucket.
+
+        """
+        self.bucket_name = bucket_name
+        self.message = f"access denied for cfngin_bucket {bucket_name}"
+        super().__init__()
+
+
+class CfnginBucketNotFound(CfnginError):
+    """CFNgin bucket specified or default bucket being used but it does not exist.
+
+    This can occur when using a custom stack to deploy the CFNgin bucket but the
+    custom stack does not create bucket that is expected.
+
+    """
+
+    bucket_name: str
+    message: str
+
+    def __init__(self, *, bucket_name: str) -> None:
+        """Instantiate class.
+
+        Args:
+            bucket_name: Name of the CFNgin bucket.
+
+        """
+        self.bucket_name = bucket_name
+        self.message = f"cfngin_bucket does not exist {bucket_name}"
+        super().__init__()
+
+
+class CfnginBucketRequired(CfnginError):
+    """CFNgin bucket is required to use a feature but it not provided/disabled."""
+
+    config_path: Optional[Path]
+    message: str
+
+    def __init__(
+        self, *, config_path: Optional[AnyPath] = None, reason: Optional[str] = None
+    ) -> None:
+        """Instantiate class.
+
+        Args:
+            config_path: Path to the CFNgin config file.
+            reason: Reason why CFNgin bucket is needed.
+
+        """
+        self.message = "cfngin_bucket is required"
+        if reason:
+            self.message += f"; {reason}"
+        if isinstance(config_path, str):
+            config_path = Path(config_path)
+        if config_path:
+            self.message += f" ({config_path})"
+        self.config_path = config_path
+        super().__init__()
+
+
 class ChangesetDidNotStabilize(CfnginError):
     """Raised when the applying a changeset fails."""
 
@@ -35,9 +110,7 @@ class ChangesetDidNotStabilize(CfnginError):
 
         """
         self.id = change_set_id
-        self.message = "Changeset '%s' did not reach a completed state." % (
-            change_set_id
-        )
+        self.message = f"Changeset '{change_set_id}' did not reach a completed state."
         super().__init__()
 
 
@@ -60,9 +133,8 @@ class GraphError(CfnginError):
         self.dependency = dependency
         self.exception = exception
         self.message = (
-            "Error detected when adding '{}' as a dependency of '{}': {}".format(
-                dependency, stack, str(exception)
-            )
+            f"Error detected when adding '{dependency}' "
+            f"as a dependency of '{stack}': {exception}"
         )
         super().__init__()
 
@@ -72,15 +144,15 @@ class ImproperlyConfigured(CfnginError):
 
     message: str
 
-    def __init__(self, cls: Any, error: Exception, *args: Any, **kwargs: Any) -> None:
+    def __init__(self, kls: Any, error: Exception, *args: Any, **kwargs: Any) -> None:
         """Instantiate class.
 
         Args:
-            cls: The class that was improperly configured.
+            kls: The class that was improperly configured.
             error: The exception that was raised when trying to use cls.
 
         """
-        self.message = 'Class "%s" is improperly configured: %s' % (cls, error)
+        self.message = f'Class "{kls}" is improperly configured: {error}'
         super().__init__(*args, **kwargs)
 
 
@@ -162,7 +234,7 @@ class MissingEnvironment(CfnginError):
 
         """
         self.key = key
-        self.message = "Environment missing key %s." % (key,)
+        self.message = f"Environment missing key {key}."
         super().__init__(*args, **kwargs)
 
 
@@ -243,7 +315,7 @@ class PersistentGraphCannotLock(CfnginError):
 
     def __init__(self, reason: str) -> None:
         """Instantiate class."""
-        self.message = "Could not lock persistent graph; %s" % reason
+        self.message = f"Could not lock persistent graph; {reason}"
         super().__init__()
 
 
@@ -254,7 +326,7 @@ class PersistentGraphCannotUnlock(CfnginError):
 
     def __init__(self, reason: Union[Exception, str]) -> None:
         """Instantiate class."""
-        self.message = "Could not unlock persistent graph; %s" % reason
+        self.message = f"Could not unlock persistent graph; {reason}"
         super().__init__()
 
 
@@ -268,16 +340,17 @@ class PersistentGraphLocked(CfnginError):
     message: str
 
     def __init__(
-        self, message: Optional[str] = None, reason: Optional[str] = None
+        self, *, message: Optional[str] = None, reason: Optional[str] = None
     ) -> None:
         """Instantiate class."""
         if message:
             self.message = message
         else:
-            self.message = "Persistant graph is locked. {}".format(
+            reason = (
                 reason
-                or ("This action requires the graph to be unlocked to be executed.")
+                or "This action requires the graph to be unlocked to be executed."
             )
+            self.message = f"Persistant graph is locked. {reason}"
         super().__init__()
 
 
@@ -316,10 +389,10 @@ class PersistentGraphUnlocked(CfnginError):
         if message:
             self.message = message
         else:
-            self.message = "Persistant graph is unlocked. {}".format(
-                reason
-                or ("This action requires the graph to be locked to be executed.")
+            reason = (
+                reason or "This action requires the graph to be locked to be executed."
             )
+            self.message = f"Persistant graph is unlocked. {reason}"
         super().__init__()
 
 
