@@ -83,7 +83,7 @@ DEFAULT_CAPABILITIES = ["CAPABILITY_NAMED_IAM", "CAPABILITY_AUTO_EXPAND"]
 
 def get_cloudformation_client(session: boto3.Session) -> CloudFormationClient:
     """Get CloudFormaiton boto3 client."""
-    config = Config(retries=dict(max_attempts=MAX_ATTEMPTS))
+    config = Config(retries={"max_attempts": MAX_ATTEMPTS})
     return session.client("cloudformation", config=config)
 
 
@@ -100,7 +100,8 @@ def get_output_dict(stack: StackTypeDef) -> Dict[str, str]:
     if not stack.get("Outputs"):
         return {}
     outputs = {
-        output["OutputKey"]: output["OutputValue"]
+        # both of these should exist even if the schema says they may not
+        output["OutputKey"]: output["OutputValue"]  # type: ignore
         for output in stack.get("Outputs", [])
     }
     LOGGER.debug("%s stack outputs: %s", stack["StackName"], json.dumps(outputs))
@@ -155,7 +156,7 @@ def get_change_set_name() -> str:
     And must be unique across all change sets.
 
     """
-    return "change-set-{}".format(int(time.time()))
+    return f"change-set-{int(time.time())}"
 
 
 def requires_replacement(changeset: List[ChangeTypeDef]) -> List[ChangeTypeDef]:
@@ -166,7 +167,9 @@ def requires_replacement(changeset: List[ChangeTypeDef]) -> List[ChangeTypeDef]:
 
     """
     return [
-        r for r in changeset if r["ResourceChange"].get("Replacement", False) == "True"
+        r
+        for r in changeset
+        if r.get("ResourceChange", {}).get("Replacement", False) == "True"
     ]
 
 
@@ -192,7 +195,7 @@ def output_full_changeset(
     if answer == "n":
         return
     if answer in ["y", "v"]:
-        msg = "%s full changeset" % (fqn) if fqn else "Full changeset"
+        msg = f"{fqn if fqn else 'Full changeset'} full changeset"
         if params_diff:
             LOGGER.info(
                 "%s:\n\n%s\n%s",
@@ -231,7 +234,7 @@ def ask_for_approval(
         approval_options.append("v")
 
     approve = ui.ask(
-        "Execute the above changes? [{}] ".format("/".join(approval_options))
+        f"Execute the above changes? [{'/'.join(approval_options)}] "
     ).lower()
 
     if include_verbose and approve == "v":
@@ -270,12 +273,11 @@ def output_summary(
     replacements: List[Any] = []
     changes: List[Any] = []
     for change in changeset:
-        resource = change["ResourceChange"]
-        replacement = cast(str, resource.get("Replacement", "")) == "True"
-        summary = "- %s %s (%s)" % (
-            resource["Action"],
-            resource["LogicalResourceId"],
-            resource["ResourceType"],
+        resource = change.get("ResourceChange", {})
+        replacement = resource.get("Replacement", "") == "True"
+        summary = (
+            f"- {resource.get('Action')} {resource.get('LogicalResourceId')} "
+            f"({resource.get('ResourceType')})"
         )
         if replacement:
             replacements.append(summary)
@@ -292,7 +294,7 @@ def output_summary(
     if changes:
         if summary:
             summary += "\n"
-        summary += "Changes:\n%s" % ("\n".join(changes))
+        summary += "Changes:\n" + "\n".join(changes)
     LOGGER.info("%s %s:\n%s", fqn, action, summary)
 
 
@@ -307,15 +309,15 @@ def summarize_params_diff(params_diff: List[DictValue[Any, Any]]) -> str:
 
     added_summary = [v.key for v in params_diff if v.status() is DictValue.ADDED]
     if added_summary:
-        summary += "Parameters Added: %s\n" % ", ".join(added_summary)
+        summary += f"Parameters Added: {', '.join(added_summary)}\n"
 
     removed_summary = [v.key for v in params_diff if v.status() is DictValue.REMOVED]
     if removed_summary:
-        summary += "Parameters Removed: %s\n" % ", ".join(removed_summary)
+        summary += f"Parameters Removed: {', '.join(removed_summary)}\n"
 
     modified_summary = [v.key for v in params_diff if v.status() is DictValue.MODIFIED]
     if modified_summary:
-        summary += "Parameters Modified: %s\n" % ", ".join(modified_summary)
+        summary += f"Parameters Modified: {', '.join(modified_summary)}\n"
 
     return summary
 
@@ -559,7 +561,7 @@ class ProviderBuilder:
         """Get or create the provider for the given region and profile."""
         with self.lock:
             # memorization lookup key derived from region + profile.
-            key = "{}-{}".format(profile, region)
+            key = f"{profile}-{region}"
             try:
                 # assume provider is in provider dictionary.
                 provider = self.providers[key]
@@ -718,14 +720,15 @@ class Provider(BaseProvider):
         def _log_func(event: StackEventTypeDef) -> None:
             template = "[%s] %s %s %s"
             event_args = [
-                event["LogicalResourceId"],
-                event["ResourceType"],
-                event["ResourceStatus"],
+                event.get("LogicalResourceId"),
+                event.get("ResourceType"),
+                event.get("ResourceStatus"),
             ]
             if event.get("ResourceStatusReason"):
                 template += " (%s)"
-                event_args.append(event["ResourceStatusReason"])
-            LOGGER.verbose(template, *([stack.fqn] + event_args))
+                event_args.append(event.get("ResourceStatusReason"))
+            event_args.insert(0, stack.fqn)
+            LOGGER.verbose(template, *event_args)
 
         log_func = log_func or _log_func
         retries = retries or MAX_TAIL_RETRIES
@@ -760,9 +763,13 @@ class Provider(BaseProvider):
 
     @staticmethod
     def _tail_print(event: StackEventTypeDef) -> None:
-        print(
+        print(  # noqa: T001
             "%s %s %s"
-            % (event["ResourceStatus"], event["ResourceType"], event["EventId"])
+            % (
+                event.get("ResourceStatus"),
+                event.get("ResourceType"),
+                event.get("EventId"),
+            )
         )
 
     def get_delete_failed_status_reason(self, stack_name: str) -> Optional[str]:
@@ -1079,10 +1086,10 @@ class Provider(BaseProvider):
 
         if self.interactive:
             sys.stdout.write(
-                'The "%s" stack is in a failed state (%s).\n'
+                f'The "{stack_name}" stack is in a failed state ({stack_status}).\n'
                 "It cannot be updated, but it can be deleted and re-created.\n"
                 "All its current resources will IRREVERSIBLY DESTROYED.\n"
-                "Proceed carefully!\n\n" % (stack_name, stack_status)
+                "Proceed carefully!\n\n"
             )
             sys.stdout.flush()
 
@@ -1163,7 +1170,7 @@ class Provider(BaseProvider):
         """
         stack = self.get_stack(fqn)
 
-        if stack["EnableTerminationProtection"] != termination_protection:
+        if stack.get("EnableTerminationProtection", False) != termination_protection:
             LOGGER.debug(
                 '%s:updating termination protection of stack to "%s"',
                 fqn,
@@ -1208,17 +1215,12 @@ class Provider(BaseProvider):
 
         approval_options = ["y", "n"]
         with ui:
+            description = "temporary " if action == "diff" else ""
+            detail = " created to generate a change set" if action == "diff" else ""
             approval = (
                 approval
                 or ui.ask(
-                    "Destroy {description}stack '{fqn}'{detail}? [{opts}] ".format(
-                        description="temporary " if action == "diff" else "",
-                        fqn=fqn,
-                        detail=" created to generate a change set"
-                        if action == "diff"
-                        else "",
-                        opts="/".join(approval_options),
-                    )
+                    f"Destroy {description}stack '{fqn}'{detail}? [{'/'.join(approval_options)}] "
                 ).lower()
             )
 
@@ -1231,9 +1233,9 @@ class Provider(BaseProvider):
             if "TerminationProtection" in err.response["Error"]["Message"]:
                 approval = ui.ask(
                     "Termination protection is enabled for "
-                    "stack '{}'.\nWould you like to disable it "
+                    f"stack '{fqn}'.\nWould you like to disable it "
                     "and try destroying the stack again? "
-                    "[{}] ".format(fqn, "/".join(approval_options))
+                    f"[{'/'.join(approval_options)}] "
                 ).lower()
                 if approval == "y":
                     self.update_termination_protection(fqn, False)
@@ -1279,10 +1281,8 @@ class Provider(BaseProvider):
                 x
                 if "ParameterValue" in x
                 else {
-                    "ParameterKey": x["ParameterKey"],
-                    "ParameterValue": cast(
-                        str, old_parameters_as_dict[x["ParameterKey"]]
-                    ),
+                    "ParameterKey": x["ParameterKey"],  # type: ignore
+                    "ParameterValue": old_parameters_as_dict[x["ParameterKey"]],  # type: ignore
                 }
                 for x in parameters
             ]
@@ -1443,7 +1443,7 @@ class Provider(BaseProvider):
     @staticmethod
     def get_stack_tags(stack: StackTypeDef) -> List[TagTypeDef]:
         """Get stack tags."""
-        return stack["Tags"]
+        return stack.get("Tags", [])
 
     def get_outputs(
         self, stack_name: str, *_args: Any, **_kwargs: Any
@@ -1463,7 +1463,7 @@ class Provider(BaseProvider):
         self, stack: StackTypeDef
     ) -> Tuple[str, Dict[str, Union[List[str], str]]]:
         """Get the template and parameters of the stack currently in AWS."""
-        stack_name = stack["StackId"]
+        stack_name = stack.get("StackId", "None")
 
         try:
             template = self.cloudformation.get_template(StackName=stack_name)[
@@ -1530,8 +1530,8 @@ class Provider(BaseProvider):
                 x
                 if "ParameterValue" in x
                 else {
-                    "ParameterKey": x["ParameterKey"],
-                    "ParameterValue": cast(str, old_params[x["ParameterKey"]]),
+                    "ParameterKey": x["ParameterKey"],  # type: ignore
+                    "ParameterValue": old_params[x["ParameterKey"]],  # type: ignore
                 }
                 for x in parameters
             ]
@@ -1571,9 +1571,13 @@ class Provider(BaseProvider):
             if resc_change.get("Type") == "Add":
                 continue  # we don't care about anything new
             # scope of changes that can invalidate a change
-            if resc_change and (
-                resc_change.get("Replacement") == "True"
-                or "Properties" in resc_change["Scope"]
+            if (
+                resc_change
+                and (
+                    resc_change.get("Replacement") == "True"
+                    or "Properties" in resc_change.get("Scope", {})
+                )
+                and "LogicalResourceId" in resc_change
             ):
                 LOGGER.debug(
                     "%s:added to invalidation list: %s",
@@ -1597,9 +1601,7 @@ class Provider(BaseProvider):
             if output_name not in self._outputs[stack.fqn]:
                 self._outputs[stack.fqn][
                     output_name
-                ] = "<inferred-change: {}.{}={}>".format(
-                    stack.fqn, output_name, str(output_params["Value"])
-                )
+                ] = f"<inferred-change: {stack.fqn}.{output_name}={output_params['Value']}>"
 
         # when creating a changeset for a new stack, CFN creates a temporary
         # stack with a status of REVIEW_IN_PROGRESS. this is only removed if
@@ -1627,5 +1629,6 @@ class Provider(BaseProvider):
     ) -> Dict[str, Union[List[str], str]]:
         """Parameters as dict."""
         return {
-            param["ParameterKey"]: param["ParameterValue"] for param in parameters_list
+            param["ParameterKey"]: param["ParameterValue"]  # type: ignore
+            for param in parameters_list
         }
