@@ -7,12 +7,15 @@ import sys
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, cast
 
+from typing_extensions import Literal
+
 from .._logging import PrefixAdaptor
 from ..compat import cached_property
 from ..config.models.runway.options.k8s import RunwayK8sModuleOptionsDataModel
 from ..core.components import DeployEnvironment
-from ..env_mgr.kbenv import KB_VERSION_FILENAME, KBEnvManager
-from ..utils import DOC_SITE, which
+from ..env_mgr.kbenv import KBEnvManager
+from ..exceptions import KubectlVersionNotSpecified
+from ..utils import which
 from .base import ModuleOptions, RunwayModule
 from .utils import run_module_command
 
@@ -22,6 +25,28 @@ if TYPE_CHECKING:
 
 LOGGER = cast("RunwayLogger", logging.getLogger(__name__))
 
+KubectlCommandTypeDef = Literal[
+    "annotation",
+    "apply",
+    "auth",
+    "autoscale",
+    "cp",
+    "create",
+    "delete",
+    "describe",
+    "diff",
+    "edit",
+    "exec",
+    "expose",
+    "get",
+    "kustomize",
+    "label",
+    "logs",
+    "patch",
+    "port-forward",
+    "proxy",
+]
+
 
 class K8s(RunwayModule):
     """Kubectl Runway Module."""
@@ -71,7 +96,27 @@ class K8s(RunwayModule):
         # logger needs to be created here to use the correct logger
         self.logger = PrefixAdaptor(self.name, LOGGER)
 
-    @property
+    @cached_property
+    def kbenv(self) -> KBEnvManager:
+        """Kubectl environmet manager."""
+        return KBEnvManager(self.path)
+
+    @cached_property
+    def kubectl_bin(self) -> str:
+        """Path to kubectl binary."""
+        try:
+            return self.kbenv.install(self.options.kubectl_version)
+        except KubectlVersionNotSpecified as exc:
+            self.logger.verbose("kubectl version not specified; checking path")
+            if not which("kubectl"):
+                self.logger.error(
+                    "kubectl not available and a version to install not specified"
+                )
+                self.logger.error(exc.message)
+                sys.exit(1)
+            return "kubectl"
+
+    @cached_property
     def skip(self) -> bool:
         """Determine if the module should be skipped."""
         if self.options.kustomize_config.is_file():
@@ -91,78 +136,99 @@ class K8s(RunwayModule):
         )
         return True
 
-    def run_kubectl(self, command: str = "plan") -> Dict[str, bool]:
-        """Run kubectl."""
-        if self.skip:
-            return {"skipped_configs": True}
-
-        if self.options.kubectl_version:
-            self.logger.verbose("using kubectl version from the module definition")
-            k8s_bin = KBEnvManager(self.path).install(self.options.kubectl_version)
-        elif (self.options.overlay_path / KB_VERSION_FILENAME).is_file():
-            self.logger.verbose(
-                "using kubectl version from the overlay directory: %s",
-                self.options.overlay_path,
-            )
-            k8s_bin = KBEnvManager(self.options.overlay_path).install()
-        elif (self.path / KB_VERSION_FILENAME).is_file():
-            self.logger.verbose(
-                "using kubectl version from the module directory: %s", self.path
-            )
-            k8s_bin = KBEnvManager(self.path).install()
-        elif (self.ctx.env.root_dir / KB_VERSION_FILENAME).is_file():
-            file_path = self.ctx.env.root_dir / KB_VERSION_FILENAME
-            self.logger.verbose(
-                "using kubectl version from the project's root directory: %s",
-                file_path,
-            )
-            k8s_bin = KBEnvManager(self.ctx.env.root_dir).install()
-        else:
-            self.logger.verbose("kubectl version not specified; checking path")
-            if not which("kubectl"):
-                self.logger.error(
-                    "kubectl not available and a version to install not specified"
-                )
-                self.logger.error(
-                    "learn how to use Runway to manage kubectl versions at %s"
-                    "/page/kubernetes/advanced_features.html#version-management",
-                    DOC_SITE,
-                )
-                sys.exit(1)
-            k8s_bin = "kubectl"
-
-        kustomize_cmd = [k8s_bin, "kustomize", str(self.options.overlay_path)]
-        self.logger.debug("running kubectl command: %s", " ".join(kustomize_cmd))
-        kustomize_yml = subprocess.check_output(
-            kustomize_cmd, env=self.ctx.env.vars
-        ).decode()
-        if command == "plan":
-            self.logger.info("yaml was generated by kubectl:\n\n%s", kustomize_yml)
-        else:
-            self.logger.debug("yaml generated by kubectl:\n\n%s", kustomize_yml)
-        if command in ["apply", "delete"]:
-            kubectl_command = [k8s_bin, command]
-            if command == "delete":
-                kubectl_command.append("--ignore-not-found=true")
-            kubectl_command.extend(["-k", str(self.options.overlay_path)])
-
-            self.logger.info("%s (in progress)", command)
-            self.logger.debug("running kubectl command: %s", " ".join(kubectl_command))
-            run_module_command(kubectl_command, self.ctx.env.vars, logger=self.logger)
-            self.logger.info("%s (complete)", command)
-        return {"skipped_configs": False}
-
-    def plan(self) -> None:
-        """Run kustomize build and display generated plan."""
-        self.run_kubectl(command="plan")
-
     def deploy(self) -> None:
         """Run kubectl apply."""
-        self.run_kubectl(command="apply")
+        if self.skip:
+            return
+        self.kubectl_kustomize()
+        self.kubectl_apply()
 
     def destroy(self) -> None:
         """Run kubectl delete."""
-        self.run_kubectl(command="delete")
+        if self.skip:
+            return
+        self.kubectl_kustomize()
+        self.kubectl_delete()
+
+    def gen_cmd(
+        self,
+        command: KubectlCommandTypeDef,
+        args_list: Optional[List[str]] = None,
+    ) -> List[str]:
+        """Generate and log a kubectl command.
+
+        This does not execute the command, only prepares it for use.
+
+        Args:
+            command: The CDK command to be executed.
+            args_list: Additional arguments to include in the generated command.
+
+        Returns:
+            The full command to be passed into a subprocess.
+
+        """
+        cmd_list = [self.kubectl_bin, command]
+        cmd_list.extend(args_list or [])
+        if command in ["apply", "delete"]:
+            cmd_list.extend(["--kustomize", str(self.options.overlay_path)])
+            if command == "delete":
+                cmd_list.append("--ignore-not-found=true")
+        elif command == "kustomize":
+            cmd_list.append(str(self.options.overlay_path))
+        LOGGER.debug("running command: %s", " ".join(cmd_list))
+        return cmd_list
+
+    def init(self) -> None:
+        """Run init."""
+        LOGGER.warning("init not currently supported for %s", self.__class__.__name__)
+
+    def kubectl_apply(self) -> None:
+        """Execute ``kubectl apply`` command.
+
+        https://kubectl.docs.kubernetes.io/references/kubectl/apply/
+
+        """
+        self.logger.info("deploy (in progress)")
+        run_module_command(
+            cmd_list=self.gen_cmd("apply"),
+            env_vars=self.ctx.env.vars,
+            logger=self.logger,
+        )
+        self.logger.info("deploy (complete)")
+
+    def kubectl_delete(self) -> None:
+        """Execute ``kubectl delete`` command.
+
+        https://kubectl.docs.kubernetes.io/references/kubectl/delete/
+
+        """
+        self.logger.info("destroy (in progress)")
+        run_module_command(
+            cmd_list=self.gen_cmd("delete"),
+            env_vars=self.ctx.env.vars,
+            logger=self.logger,
+        )
+        self.logger.info("destroy (complete)")
+
+    def kubectl_kustomize(self) -> str:
+        """Execute ``kubectl kustomize`` command.
+
+        https://kubectl.docs.kubernetes.io/references/kubectl/kustomize/
+
+        """
+        kustomize_yml = subprocess.check_output(
+            self.gen_cmd("kustomize"), env=self.ctx.env.vars
+        ).decode()
+        self.logger.debug("kustomized yaml generated by kubectl:\n\n%s", kustomize_yml)
+        return kustomize_yml
+
+    def plan(self) -> None:
+        """Run kustomize build and display generated plan."""
+        if self.skip:
+            return
+        self.logger.info(
+            "kustomized yaml generated by kubectl:\n\n%s", self.kubectl_kustomize()
+        )
 
 
 class K8sOptions(ModuleOptions):
