@@ -27,7 +27,7 @@ def get_principal_arn(context: CfnginContext) -> str:
     # looking up caller identity
     session = context.get_session()
     sts_client = session.client("sts")
-    caller_identity_arn = sts_client.get_caller_identity()["Arn"]
+    caller_identity_arn = sts_client.get_caller_identity().get("Arn", "")
     if caller_identity_arn.split(":")[2] == "iam" and (
         caller_identity_arn.split(":")[5].startswith("user/")
     ):
@@ -59,7 +59,7 @@ def generate(
     overlay_path.mkdir(parents=True, exist_ok=True)
     principal_arn = get_principal_arn(context)
     node_instancerole_arn = OutputLookup.handle(
-        "%s::NodeInstanceRoleArn" % stack, context=context
+        f"{stack}::NodeInstanceRoleArn", context=context
     )
     aws_authmap_template = (Path(__file__).parent / "aws-auth-cm.yaml").read_text()
     file_path.write_text(
