@@ -30,7 +30,7 @@ def aws_eks_update_kubeconfig(context: CfnginContext, **kwargs: Any) -> bool:
         eks_cluster_name = kwargs["cluster-name"]
     else:
         eks_cluster_name = OutputLookup.handle(
-            "%s::EksClusterName" % kwargs["stack"], context=context
+            f"{kwargs['stack']}::EksClusterName", context=context
         )
     LOGGER.info("writing kubeconfig...")
     subprocess.check_output(
@@ -44,8 +44,8 @@ def aws_eks_update_kubeconfig(context: CfnginContext, **kwargs: Any) -> bool:
     if not os.environ.get("PIPENV_ACTIVE") and (
         not os.environ.get("VIRTUAL_ENV") and not which("aws")
     ):
-        print("", file=sys.stderr)
-        print(
+        print("", file=sys.stderr)  # noqa: T001
+        print(  # noqa: T001
             "Warning: the generated kubeconfig uses the aws-cli for "
             "authentication, but it is not found in your environment. ",
             file=sys.stderr,
